==> gcc-java-4.1-20060421.tar.bz2: gcc-4.1-20060421/libjava/classpath/javax/print/attribute/standard/DateTimeAtProcessing.java <==
/* DateTimeAtProcessing.java -- 
   Copyright (C) 2003, 2004  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.print.attribute.standard;

import java.util.Date;

import javax.print.attribute.DateTimeSyntax;
import javax.print.attribute.PrintJobAttribute;

/**
 * @author Michael Koch (konqueror@gmx.de)
 */
public final class DateTimeAtProcessing extends DateTimeSyntax
  implements PrintJobAttribute
{
  private static final long serialVersionUID = -3710068197278263244L;

  /**
   * Creates a <code>DateTimeAtProcessing</code> object.
   *
   * @param value the date at processing time
   *
   * @exception NullPointerException if value is null
   */
  public DateTimeAtProcessing(Date value)
  {
    super(value);
  }

  /**
   * Tests of obj is equal to this object.
   *
   * @param obj the object to test
   *
   * @return true if both objects are equal, false otherwise.
   */
  public boolean equals(Object obj)
  {
    if(! (obj instanceof DateTimeAtProcessing))
      return false;

    return super.equals(obj);
  }

  /**
   * Returns category of this class.
   *
   * @return the class <code>DateTimeAtProcessing</code> itself
   */
  public Class getCategory()
  {
    return DateTimeAtProcessing.class;
  }

  /**
   * Returns name of this class.
   *
   * @return the string "date-time-at-processing"
   */
  public String getName()
  {
    return "date-time-at-processing";
  }
}

==> gcc-java-4.6-20101106.tar.bz2: gcc-4.6-20101106/libjava/classpath/javax/print/attribute/standard/DateTimeAtProcessing.java <==
/* DateTimeAtProcessing.java -- 
   Copyright (C) 2003, 2004, 2005  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package javax.print.attribute.standard;

import java.util.Date;

import javax.print.attribute.Attribute;
import javax.print.attribute.DateTimeSyntax;
import javax.print.attribute.PrintJobAttribute;

/**
 * The <code>DateTimeAtProcessing</code> attribute specifies the date
 * and the time at which a print job started processing.
 * <p>
 * <b>IPP Compatibility:</b> DateTimeAtProcessing is an IPP 1.1 attribute.
 * </p>
 * @see javax.print.attribute.standard.DateTimeAtCompleted
 * @see javax.print.attribute.standard.DateTimeAtCreation
 * 
 * @author Michael Koch (konqueror@gmx.de)
 */
public final class DateTimeAtProcessing extends DateTimeSyntax
  implements PrintJobAttribute
{
  private static final long serialVersionUID = -3710068197278263244L;

  /**
   * Creates a <code>DateTimeAtProcessing</code> object.
   *
   * @param value the date at processing time
   *
   * @exception NullPointerException if value is null
   */
  public DateTimeAtProcessing(Date value)
  {
    super(value);
  }

  /**
   * Tests if the given object is equal to this object.
   *
   * @param obj the object to test
   *
   * @return <code>true</code> if both objects are equal, 
   * <code>false</code> otherwise.
   */
  public boolean equals(Object obj)
  {
    if(! (obj instanceof DateTimeAtProcessing))
      return false;

    return super.equals(obj);
  }

  /**
   * Returns category of this class.
   *
   * @return The class <code>DateTimeAtProcessing</code> itself.
   */
  public Class< ? extends Attribute> getCategory()
  {
    return DateTimeAtProcessing.class;
  }

  /**
   * Returns the name of this attribute.
   *
   * @return The name "date-time-at-processing".
   */
  public String getName()
  {
    return "date-time-at-processing";
  }
}
